@@ -1,3 +1,4 @@
+import enum
 from functools import partial
 from typing import Mapping, Iterable
 
@@ -7,9 +8,25 @@ from PySide2 import QtWidgets
 from . import common
 from . import extend
 
-__all__ = ('CONTEXT_CLIPBOARD',)
+__all__ = ('CONTEXT_CLIPBOARD', 'ActionContext')
 
-CONTEXT_CLIPBOARD = 'clipboard'
+
+class AutoNumber(enum.Enum):
+
+    def __new__(cls):
+        value = len(cls.__members__) + 1
+        obj = object.__new__(cls)
+        obj._value_ = value
+        return obj
+
+
+class ActionContext(AutoNumber):
+    PARENT = ()
+    CLIPBOARD = ()
+    DATABASE = ()
+
+
+CONTEXT_CLIPBOARD = ActionContext.CLIPBOARD
 
 
 class ActionController(QObject):
